==> mgserver-0.1.0.tgz: package/lib/nginx-template.js <==
const defaultServer = `
server {
    listen 80 default_server;
    listen [::]:80 default_server;

    root /var/www/html;

    index index.html index.htm index.nginx-debian.html;

    server_name _;

    location /.well-known/acme-challenge {
        allow all;
        root /le-root;
        try_files $uri =404;
    }

    location / {
        try_files $uri =404;
    }
}
`;

const sslServer = ({ letsencryptDirPath, primaryDomain, proxyPass }) => `
server {
    listen [::]:443 ssl ipv6only=on; # managed by Certbot
    listen 443 ssl; # managed by Certbot
    ssl_certificate ${letsencryptDirPath}/fullchain.pem; # managed by Certbot
    ssl_certificate_key ${letsencryptDirPath}/privkey.pem; # managed by Certbot
    include /etc/letsencrypt/options-ssl-nginx.conf; # managed by Certbot
    ssl_dhparam /etc/letsencrypt/ssl-dhparams.pem; # managed by Certbot

    root /var/www/html;

    # Add index.php to the list if you are using PHP
    index index.html index.htm index.nginx-debian.html;

    server_name ${primaryDomain}; # managed by Certbot

    location /.well-known/acme-challenge {
        allow all;
        root /le-root;
        try_files $uri =404;
    }

    location / {
        proxy_pass ${proxyPass};
        proxy_set_header X-Real-IP $remote_addr;
        proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
        proxy_set_header X-Forwarded-Host $host;
        proxy_set_header X-Forwarded-Proto $scheme;
        proxy_set_header upgrade $http_upgrade;
        proxy_set_header connection 'upgrade';
        proxy_set_header host $host;
        proxy_cache_bypass $http_upgrade;
    }
}
`;

const sslRedirectServer = ({ letsencryptDirPath, serverName, primaryDomain }) => `
server {
    listen 443 ssl;
    server_name ${serverName};
    ssl_certificate ${letsencryptDirPath}/fullchain.pem;
    ssl_certificate_key ${letsencryptDirPath}/privkey.pem;
    return 301 https://${primaryDomain}$request_uri;
}
`;

const nonSSLRedirectServer = ({ primaryDomain, alternativeDomainNames }) => `
server {
    listen 80;
    listen [::]:80;
    server_name ${[primaryDomain].concat(alternativeDomainNames).join(' ')};
    return 301 https://${primaryDomain}$request_uri;
}
`;

const make = ({
    letsencryptDirPath,
    primaryDomain,
    alternativeDomainNames = [],
    proxyPass = 'http://localhost:5000',
}) => `
${sslServer({ letsencryptDirPath, primaryDomain, proxyPass })}
${alternativeDomainNames
    .map((serverName) => sslRedirectServer({ letsencryptDirPath, serverName, primaryDomain }))
    .join('\n')}
${nonSSLRedirectServer({ primaryDomain, alternativeDomainNames })}
`;

module.exports = {
    defaultServer,
    sslServer,
    sslRedirectServer,
    nonSSLRedirectServer,
    make,
};

==> mgserver-0.2.0.tgz: package/lib/nginx-template.js <==
const defaultServer = `
server {
    listen 80 default_server;
    listen [::]:80 default_server;

    root /var/www/html;

    index index.html index.htm index.nginx-debian.html;

    server_name _;

    location / {
        try_files $uri $uri/ =404;
    }
}
`;

const sslServer = ({ letsencryptDirPath, primaryDomain, proxyPass }) => `
server {
    listen [::]:443 ssl ipv6only=on; # managed by Certbot
    listen 443 ssl; # managed by Certbot
    ssl_certificate ${letsencryptDirPath}/fullchain.pem; # managed by Certbot
    ssl_certificate_key ${letsencryptDirPath}/privkey.pem; # managed by Certbot
    include /etc/letsencrypt/options-ssl-nginx.conf; # managed by Certbot
    ssl_dhparam /etc/letsencrypt/ssl-dhparams.pem; # managed by Certbot

    root /var/www/html;

    # Add index.php to the list if you are using PHP
    index index.html index.htm index.nginx-debian.html;

    server_name ${primaryDomain}; # managed by Certbot

    location /.well-known/acme-challenge {
        allow all;
        root /le-root;
        try_files $uri =404;
    }

    location / {
        proxy_pass ${proxyPass};
        proxy_set_header X-Real-IP $remote_addr;
        proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
        proxy_set_header X-Forwarded-Host $host;
        proxy_set_header X-Forwarded-Proto $scheme;
        proxy_set_header upgrade $http_upgrade;
        proxy_set_header connection 'upgrade';
        proxy_set_header host $host;
        proxy_cache_bypass $http_upgrade;
    }
}
`;

const sslRedirectServer = ({ letsencryptDirPath, serverName, primaryDomain }) => `
server {
    listen 443 ssl;
    server_name ${serverName};
    ssl_certificate ${letsencryptDirPath}/fullchain.pem;
    ssl_certificate_key ${letsencryptDirPath}/privkey.pem;
    return 301 https://${primaryDomain}$request_uri;
}
`;

const nonSSLRedirectServer = ({ primaryDomain, alternativeDomainNames }) => `
server {
    listen 80;
    listen [::]:80;
    server_name ${[primaryDomain].concat(alternativeDomainNames).join(' ')};
    return 301 https://${primaryDomain}$request_uri;
}
`;

const make = ({
    letsencryptDirPath,
    primaryDomain,
    alternativeDomainNames = [],
    proxyPass = 'http://localhost:5000',
}) => `
${sslServer({ letsencryptDirPath, primaryDomain, proxyPass })}
${alternativeDomainNames
    .map((serverName) =>
        sslRedirectServer({ letsencryptDirPath, serverName, primaryDomain })
    )
    .join('\n')}
${nonSSLRedirectServer({ primaryDomain, alternativeDomainNames })}
`;

module.exports = {
    defaultServer,
    sslServer,
    sslRedirectServer,
    nonSSLRedirectServer,
    make,
};
